@@ -5,7 +5,7 @@
 Nayatani (1995) Colour Appearance Model
 =======================================
 
-Defines *Nayatani (1995)* colour appearance model objects:
+Defines Nayatani (1995) colour appearance model objects:
 
 -   :class:`Nayatani95_Specification`
 -   :func:`XYZ_to_Nayatani95`
@@ -17,25 +17,26 @@ See Also
 
 References
 ----------
-.. [1]  **Mark D. Fairchild**, *Color Appearance Models, 3nd Edition*,
-        The Wiley-IS&T Series in Imaging Science and Technology,
-        published June 2013, ASIN: B00DAYO8E2,
-        Locations 4810-5085.
-.. [2]  **Y. Nayatani, H. Sobagaki & K. H. T. Yano**,
-        *Lightness dependency of chroma scales of a nonlinear color-appearance
-        model and its latest formulation*,
-        *Color Research & Application, Volume 20, Issue 3, pages 156–167,
-        June 1995*,
-        DOI: http://dx.doi.org/10.1002/col.5080200305
+.. [1]  Fairchild, M. D. (2013). The Nayatani et al. Model. In Color
+        Appearance Models (3rd ed., pp. 4810–5085). Wiley. ASIN:B00DAYO8E2
+.. [2]  Nayatani, Y., Sobagaki, H., & Yano, K. H. T. (1995). Lightness
+        dependency of chroma scales of a nonlinear color-appearance model and
+        its latest formulation. Color Research & Application, 20(3), 156–167.
+        doi:10.1002/col.5080200305
 """
 
 from __future__ import division, unicode_literals
 
-import math
 import numpy as np
 from collections import namedtuple
 
+from colour.adaptation.cie1994 import (
+    CIE1994_XYZ_TO_RGB_MATRIX,
+    beta_1,
+    exponential_factors,
+    intermediate_values)
 from colour.models import XYZ_to_xy
+from colour.utilities import warning
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013 - 2014 - Colour Developers'
@@ -49,11 +50,7 @@ __all__ = ['NAYATANI95_XYZ_TO_RGB_MATRIX',
            'Nayatani95_Specification',
            'XYZ_to_Nayatani95',
            'illuminance_to_luminance',
-           'intermediate_values',
            'XYZ_to_RGB_Nayatani95',
-           'beta_1',
-           'beta_2',
-           'chromatic_adaptation_exponential_factors',
            'scaling_coefficient',
            'achromatic_response',
            'tritanopic_response',
@@ -69,14 +66,11 @@ __all__ = ['NAYATANI95_XYZ_TO_RGB_MATRIX',
            'chroma_correlate',
            'colourfulness_components',
            'colourfulness_correlate',
-           'chromatic_strength_function', ]
+           'chromatic_strength_function']
 
-NAYATANI95_XYZ_TO_RGB_MATRIX = np.array(
-    [[0.40024, 0.70760, -0.08081],
-     [-0.22630, 1.16532, 0.04570],
-     [0.00000, 0.00000, 0.91822]])
+NAYATANI95_XYZ_TO_RGB_MATRIX = CIE1994_XYZ_TO_RGB_MATRIX
 """
-*Nayatani (1995)* colour appearance model *CIE XYZ* colourspace to cone
+Nayatani (1995) colour appearance model *CIE XYZ* colourspace to cone
 responses matrix.
 
 NAYATANI95_XYZ_TO_RGB_MATRIX : array_like, (3, 3)
@@ -88,10 +82,10 @@ class Nayatani95_ReferenceSpecification(
         'Nayatani95_ReferenceSpecification',
         ('Lstar_P', 'C', 'theta', 'S', 'B_r', 'M', 'H', 'H_C', 'Lstar_N'))):
     """
-    Defines the *Nayatani (1995)* colour appearance model reference
+    Defines the Nayatani (1995) colour appearance model reference
     specification.
 
-    This specification has field names consistent with **Mark D. Fairchild**
+    This specification has field names consistent with Fairchild (2013)
     reference.
 
     Parameters
@@ -121,11 +115,11 @@ class Nayatani95_Specification(
     namedtuple('Nayatani95_Specification',
                ('Lstar_P', 'C', 'h', 's', 'Q', 'M', 'H', 'HC', 'Lstar_N'))):
     """
-    Defines the *Nayatani (1995)* colour appearance model specification.
+    Defines the Nayatani (1995) colour appearance model specification.
 
     This specification has field names consistent with the remaining colour
-    appearance models in :mod:`colour.appearance` but diverge from
-    **Mark D. Fairchild** reference.
+    appearance models in :mod:`colour.appearance` but diverge from Fairchild
+    (2013) reference.
 
     Parameters
     ----------
@@ -157,7 +151,7 @@ def XYZ_to_Nayatani95(XYZ,
                       E_or,
                       n=1):
     """
-    Computes the *Nayatani (1995)* colour appearance model correlates.
+    Computes the Nayatani (1995) colour appearance model correlates.
 
     Parameters
     ----------
@@ -168,7 +162,7 @@ def XYZ_to_Nayatani95(XYZ,
         *CIE XYZ* colourspace matrix of reference white in domain [0, 100].
     Y_o : numeric
         Luminance factor :math:`Y_o` of achromatic background as percentage in
-        domain [0.18,]
+        domain [0.18, 1.0]
     E_o : numeric
         Illuminance :math:`E_o` of the viewing field in lux.
     E_or : numeric
@@ -180,7 +174,7 @@ def XYZ_to_Nayatani95(XYZ,
     Returns
     -------
     Nayatani95_Specification
-        *Nayatani (1995)* colour appearance model specification.
+        Nayatani (1995) colour appearance model specification.
 
     Warning
     -------
@@ -191,11 +185,6 @@ def XYZ_to_Nayatani95(XYZ,
     -   Input *CIE XYZ* colourspace matrix is in domain [0, 100].
     -   Input *CIE XYZ_n* colourspace matrix is in domain [0, 100].
 
-    Raises
-    ------
-    ValueError
-        If Luminance factor :math:`Y_o` is not greater or equal than 18%.
-
     Examples
     --------
     >>> XYZ = np.array([19.01, 20, 21.78])
@@ -207,29 +196,28 @@ def XYZ_to_Nayatani95(XYZ,
     Nayatani95_Specification(Lstar_P=49.9998829..., C=0.0133550..., h=257.5232268..., s=0.0133550..., Q=62.6266734..., M=0.0167262..., H=None, HC=None, Lstar_N=50.0039154...)
     """
 
-    if np.any(Y_o < 0.18):
-        raise ValueError(
-            'Luminance factor "Y_o" of achromatic background must '
-            'be greater or equal than 18%!')
+    if not 18 <= Y_o <= 100:
+        warning(('"Y_o" luminance factor must be in [18, 100] domain, '
+                 'unpredictable results may occur!'))
 
     X, Y, Z = np.ravel(XYZ)
 
     # Computing adapting luminance :math:`L_o` and normalising luminance
     # :math:`L_{or}` in in :math:`cd/m^2`.
-    L_o = illuminance_to_luminance(E_o, Y_o)
+    # L_o = illuminance_to_luminance(E_o, Y_o)
     L_or = illuminance_to_luminance(E_or, Y_o)
 
     # Computing :math:`\xi`, :math:`\eta`, :math:`\zeta` values.
-    xi, eta, zeta = x_e_z = intermediate_values(XYZ_n)
+    xi, eta, zeta = xez = intermediate_values(XYZ_to_xy(XYZ_n))
 
     # Computing adapting field cone responses.
-    RGB_o = ((Y_o * E_o) / (100 * np.pi)) * x_e_z
+    RGB_o = ((Y_o * E_o) / (100 * np.pi)) * xez
 
     # Computing stimulus cone responses.
     R, G, B = RGB = XYZ_to_RGB_Nayatani95(np.array([X, Y, Z]))
 
     # Computing exponential factors of the chromatic adaptation.
-    bRGB_o = chromatic_adaptation_exponential_factors(RGB_o)
+    bRGB_o = exponential_factors(RGB_o)
     bL_or = beta_1(L_or)
 
     # Computing scaling coefficients :math:`e(R)` and :math:`e(G)`
@@ -238,14 +226,14 @@ def XYZ_to_Nayatani95(XYZ,
 
     # Computing opponent colour dimensions.
     # Computing achromatic response :math:`Q`:
-    Q_response = achromatic_response(RGB, bRGB_o, x_e_z,
+    Q_response = achromatic_response(RGB, bRGB_o, xez,
                                      bL_or, eR, eG, n)
 
     # Computing tritanopic response :math:`t`:
-    t_response = tritanopic_response(RGB, bRGB_o, x_e_z, n)
+    t_response = tritanopic_response(RGB, bRGB_o, xez, n)
 
     # Computing protanopic response :math:`p`:
-    p_response = protanopic_response(RGB, bRGB_o, x_e_z, n)
+    p_response = protanopic_response(RGB, bRGB_o, xez, n)
 
     # -------------------------------------------------------------------------
     # Computing the correlate of *brightness* :math:`B_r`.
@@ -254,7 +242,7 @@ def XYZ_to_Nayatani95(XYZ,
 
     # Computing *brightness* :math:`B_{rw}` of ideal white.
     brightness_ideal_white = ideal_white_brightness_correlate(bRGB_o,
-                                                              x_e_z,
+                                                              xez,
                                                               bL_or,
                                                               n)
 
@@ -296,8 +284,8 @@ def XYZ_to_Nayatani95(XYZ,
     # Computing the correlate of *colourfulness* :math:`M`.
     # -------------------------------------------------------------------------
     # TODO: Investigate components usage.
-    M_RG, M_YB = colourfulness_components(C_RG, C_YB,
-                                          brightness_ideal_white)
+    # M_RG, M_YB = colourfulness_components(C_RG, C_YB,
+    #                                       brightness_ideal_white)
     M = colourfulness_correlate(C, brightness_ideal_white)
 
     return Nayatani95_Specification(Lstar_P,
@@ -337,38 +325,6 @@ def illuminance_to_luminance(E, Y_f):
     return Y_f * E / (100 * np.pi)
 
 
-def intermediate_values(XYZ_n):
-    """
-    Returns the intermediate values :math:`\\xi`, :math:`\eta`, :math:`\zeta`.
-
-    Parameters
-    ----------
-    XYZ_n : array_like, (3,)
-        *CIE XYZ* colourspace matrix of reference white in domain [0, 100].
-
-    Returns
-    -------
-    ndarray, (3,)
-        Intermediate values :math:`\\xi`, :math:`\eta`, :math:`\zeta`.
-
-    Examples
-    --------
-    >>> XYZ_n = np.array([95.05, 100, 108.88])
-    >>> intermediate_values(XYZ_n)  # doctest: +ELLIPSIS
-    array([ 1.0000421...,  0.9999800...,  0.9997579...])
-    """
-
-    # Illuminant chromaticity coordinates.
-    x_o, y_o = XYZ_to_xy(XYZ_n)
-
-    # Computing :math:`\xi`, :math:`\eta`, :math:`\zeta` values.
-    xi = (0.48105 * x_o + 0.78841 * y_o - 0.08081) / y_o
-    eta = (-0.27200 * x_o + 1.11962 * y_o + 0.04570) / y_o
-    zeta = (0.91822 * (1 - x_o - y_o)) / y_o
-
-    return np.array([xi, eta, zeta])
-
-
 def XYZ_to_RGB_Nayatani95(XYZ):
     """
     Converts from *CIE XYZ* colourspace to cone responses.
@@ -390,87 +346,7 @@ def XYZ_to_RGB_Nayatani95(XYZ):
     array([ 20.000520...,  19.999783...,  19.998831...])
     """
 
-    return NAYATANI95_XYZ_TO_RGB_MATRIX.dot(XYZ)
-
-
-def beta_1(x):
-    """
-    Computes the exponent :math:`\\beta_1` for the middle and long-wavelength
-    sensitive cones.
-
-    Parameters
-    ----------
-    x: numeric
-        Middle and long-wavelength sensitive cone response.
-
-    Returns
-    -------
-    numeric
-        Exponent :math:`\\beta_1`.
-
-    Examples
-    --------
-    >>> beta_1(318.323316315)  # doctest: +ELLIPSIS
-    4.6106222...
-    """
-
-    return (6.469 + 6.362 * (x ** 0.4495)) / (6.469 + (x ** 0.4495))
-
-
-def beta_2(x):
-    """
-    Computes the exponent :math:`\\beta_2` for the short-wavelength sensitive
-    cones.
-
-    Parameters
-    ----------
-    x: numeric
-        Short-wavelength sensitive cone response.
-
-    Returns
-    -------
-    numeric
-        Exponent :math:`\\beta_2`.
-
-    Examples
-    --------
-    >>> beta_2(318.323316315)  # doctest: +ELLIPSIS
-    4.6522416...
-    """
-
-    return 0.7844 * (8.414 + 8.091 * (x ** 0.5128)) / (8.414 + (x ** 0.5128))
-
-
-def chromatic_adaptation_exponential_factors(RGB_o):
-    """
-    Returns the chromatic adaptation exponential factors :math:`\\beta_1(R_o)`,
-    `math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)` of given cone responses.
-
-    Parameters
-    ----------
-    RGB_o: ndarray, (3,)
-         Cone responses.
-
-    Returns
-    -------
-    ndarray, (3,)
-        Chromatic adaptation exponential factors :math:`\\beta_1(R_o)`,
-        `math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
-
-    Examples
-    --------
-    >>> RGB_o = np.array([318.32331631, 318.30352317, 318.23283482])
-    >>> chromatic_adaptation_exponential_factors(RGB_o)  # doctest: +ELLIPSIS
-    array([ 4.6106222...,  4.6105892...,  4.6520698...])
-    """
-
-    R_o, G_o, B_o = np.ravel(RGB_o)
-
-    bR_o = beta_1(R_o)
-    bG_o = beta_1(G_o)
-    bB_o = beta_2(B_o)
-
-    return np.array([bR_o, bG_o, bB_o])
+    return np.dot(NAYATANI95_XYZ_TO_RGB_MATRIX, XYZ)
 
 
 def scaling_coefficient(x, y):
@@ -500,7 +376,7 @@ def scaling_coefficient(x, y):
     return 1.758 if x >= (20 * y) else 1
 
 
-def achromatic_response(RGB, bRGB_o, x_e_z, bL_or, eR, eG, n=1):
+def achromatic_response(RGB, bRGB_o, xez, bL_or, eR, eG, n=1):
     """
     Returns the achromatic response :math:`Q` from given stimulus cone
     responses.
@@ -511,8 +387,8 @@ def achromatic_response(RGB, bRGB_o, x_e_z, bL_or, eR, eG, n=1):
          Stimulus cone responses.
     bRGB_o: ndarray, (3,)
          Chromatic adaptation exponential factors :math:`\\beta_1(R_o)`,
-         `math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
-    x_e_z: ndarray, (3,)
+         :math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
+    xez: ndarray, (3,)
         Intermediate values :math:`\\xi`, :math:`\eta`, :math:`\zeta`.
     bL_or: numeric
          Normalising chromatic adaptation exponential factor
@@ -533,18 +409,18 @@ def achromatic_response(RGB, bRGB_o, x_e_z, bL_or, eR, eG, n=1):
     --------
     >>> RGB = np.array([20.0005206, 19.999783, 19.9988316])
     >>> bRGB_o = np.array([4.61062223, 4.61058926, 4.65206986])
-    >>> x_e_z = np.array([1.00004219, 0.99998001, 0.99975794])
+    >>> xez = np.array([1.00004219, 0.99998001, 0.99975794])
     >>> bL_or = 3.6810214956040888
     >>> eR = 1.0
     >>> eG = 1.758
     >>> n = 1.0
-    >>> achromatic_response(RGB, bRGB_o, x_e_z, bL_or, eR, eG, n)  # noqa  # doctest: +ELLIPSIS
+    >>> achromatic_response(RGB, bRGB_o, xez, bL_or, eR, eG, n)  # noqa  # doctest: +ELLIPSIS
     -0.0001169...
     """
 
     R, G, B = RGB
     bR_o, bG_o, bB_o = bRGB_o
-    xi, eta, zeta = x_e_z
+    xi, eta, zeta = xez
 
     Q = (2 / 3) * bR_o * eR * np.log10((R + n) / (20 * xi + n))
     Q += (1 / 3) * bG_o * eG * np.log10((G + n) / (20 * eta + n))
@@ -553,7 +429,7 @@ def achromatic_response(RGB, bRGB_o, x_e_z, bL_or, eR, eG, n=1):
     return Q
 
 
-def tritanopic_response(RGB, bRGB_o, x_e_z, n):
+def tritanopic_response(RGB, bRGB_o, xez, n):
     """
     Returns the tritanopic response :math:`t` from given stimulus cone
     responses.
@@ -564,8 +440,8 @@ def tritanopic_response(RGB, bRGB_o, x_e_z, n):
          Stimulus cone responses.
     bRGB_o: ndarray, (3,)
          Chromatic adaptation exponential factors :math:`\\beta_1(R_o)`,
-         `math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
-    x_e_z: ndarray, (3,)
+         :math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
+    xez: ndarray, (3,)
         Intermediate values :math:`\\xi`, :math:`\eta`, :math:`\zeta`.
     n : numeric, optional
         Noise term used in the non linear chromatic adaptation model.
@@ -579,15 +455,15 @@ def tritanopic_response(RGB, bRGB_o, x_e_z, n):
     --------
     >>> RGB = np.array([20.0005206, 19.999783, 19.9988316])
     >>> bRGB_o = np.array([4.61062223, 4.61058926, 4.65206986])
-    >>> x_e_z = np.array([1.00004219, 0.99998001, 0.99975794])
+    >>> xez = np.array([1.00004219, 0.99998001, 0.99975794])
     >>> n = 1.0
-    >>> tritanopic_response(RGB, bRGB_o, x_e_z, n)  # doctest: +ELLIPSIS
+    >>> tritanopic_response(RGB, bRGB_o, xez, n)  # doctest: +ELLIPSIS
     -1.7703650...e-05
     """
 
     R, G, B = RGB
     bR_o, bG_o, bB_o = bRGB_o
-    xi, eta, zeta = x_e_z
+    xi, eta, zeta = xez
 
     t = (1 / 1) * bR_o * np.log10((R + n) / (20 * xi + n))
     t += - (12 / 11) * bG_o * np.log10((G + n) / (20 * eta + n))
@@ -596,7 +472,7 @@ def tritanopic_response(RGB, bRGB_o, x_e_z, n):
     return t
 
 
-def protanopic_response(RGB, bRGB_o, x_e_z, n):
+def protanopic_response(RGB, bRGB_o, xez, n):
     """
     Returns the protanopic response :math:`p` from given stimulus cone
     responses.
@@ -607,8 +483,8 @@ def protanopic_response(RGB, bRGB_o, x_e_z, n):
          Stimulus cone responses.
     bRGB_o: ndarray, (3,)
          Chromatic adaptation exponential factors :math:`\\beta_1(R_o)`,
-         `math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
-    x_e_z: ndarray, (3,)
+         :math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
+    xez: ndarray, (3,)
         Intermediate values :math:`\\xi`, :math:`\eta`, :math:`\zeta`.
     n : numeric, optional
         Noise term used in the non linear chromatic adaptation model.
@@ -622,15 +498,15 @@ def protanopic_response(RGB, bRGB_o, x_e_z, n):
     --------
     >>> RGB = np.array([20.0005206, 19.999783, 19.9988316])
     >>> bRGB_o = np.array([4.61062223, 4.61058926, 4.65206986])
-    >>> x_e_z = np.array([1.00004219, 0.99998001, 0.99975794])
+    >>> xez = np.array([1.00004219, 0.99998001, 0.99975794])
     >>> n = 1.0
-    >>> protanopic_response(RGB, bRGB_o, x_e_z, n)  # doctest: +ELLIPSIS
+    >>> protanopic_response(RGB, bRGB_o, xez, n)  # doctest: +ELLIPSIS
     -8.0021426...e-05
     """
 
     R, G, B = RGB
     bR_o, bG_o, bB_o = bRGB_o
-    xi, eta, zeta = x_e_z
+    xi, eta, zeta = xez
 
     p = (1 / 9) * bR_o * np.log10((R + n) / (20 * xi + n))
     p += (1 / 9) * bG_o * np.log10((G + n) / (20 * eta + n))
@@ -647,7 +523,7 @@ def brightness_correlate(bRGB_o, bL_or, Q):
     ----------
     bRGB_o: ndarray, (3,)
          Chromatic adaptation exponential factors :math:`\\beta_1(R_o)`,
-         `math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
+         :math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
     bL_or: numeric
          Normalising chromatic adaptation exponential factor
          :math:`\\beta_1(B_or)`.
@@ -674,7 +550,7 @@ def brightness_correlate(bRGB_o, bL_or, Q):
     return B_r
 
 
-def ideal_white_brightness_correlate(bRGB_o, x_e_z, bL_or, n):
+def ideal_white_brightness_correlate(bRGB_o, xez, bL_or, n):
     """
     Returns the ideal white *brightness* correlate :math:`B_{rw}`.
 
@@ -682,8 +558,8 @@ def ideal_white_brightness_correlate(bRGB_o, x_e_z, bL_or, n):
     ----------
     bRGB_o: ndarray, (3,)
          Chromatic adaptation exponential factors :math:`\\beta_1(R_o)`,
-         `math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
-    x_e_z: ndarray, (3,)
+         :math:`\\beta_1(G_o)` and :math:`\\beta_2(B_o)`.
+    xez: ndarray, (3,)
         Intermediate values :math:`\\xi`, :math:`\eta`, :math:`\zeta`.
     bL_or: numeric
          Normalising chromatic adaptation exponential factor
@@ -699,15 +575,15 @@ def ideal_white_brightness_correlate(bRGB_o, x_e_z, bL_or, n):
     Examples
     --------
     >>> bRGB_o = np.array([4.61062223, 4.61058926, 4.65206986])
-    >>> x_e_z = np.array([1.00004219, 0.99998001, 0.99975794])
+    >>> xez = np.array([1.00004219, 0.99998001, 0.99975794])
     >>> bL_or = 3.6810214956040888
     >>> n = 1.0
-    >>> ideal_white_brightness_correlate(bRGB_o, x_e_z, bL_or, n)  # noqa  # doctest: +ELLIPSIS
+    >>> ideal_white_brightness_correlate(bRGB_o, xez, bL_or, n)  # noqa  # doctest: +ELLIPSIS
     125.2435392...
     """
 
     bR_o, bG_o, bB_o = bRGB_o
-    xi, eta, zeta = x_e_z
+    xi, eta, zeta = xez
 
     B_rw = (2 / 3) * bR_o * 1.758 * np.log10((100 * xi + n) / (20 * xi + n))
     B_rw += (1 / 3) * bG_o * 1.758 * np.log10((100 * eta + n) / (20 * eta + n))
@@ -793,7 +669,7 @@ def hue_angle(p, t):
     257.5250300...
     """
 
-    h_L = math.degrees(np.arctan2(p, t)) % 360
+    h_L = np.degrees(np.arctan2(p, t)) % 360
     return h_L
 
 
@@ -862,7 +738,7 @@ def saturation_components(h, bL_or, t, p):
     (-0.0028852..., -0.0130396...)
     """
 
-    E_s = chromatic_strength_function(math.radians(h))
+    E_s = chromatic_strength_function(np.radians(h))
     S_RG = (488.93 / bL_or) * E_s * t
     S_YB = (488.93 / bL_or) * E_s * p
 
