@@ -5,7 +5,7 @@
 RLAB Colour Appearance Model
 ============================
 
-Defines *RLAB* colour appearance model objects:
+Defines RLAB colour appearance model objects:
 
 -   :attr:`RLAB_VIEWING_CONDITIONS`
 -   :attr:`RLAB_D_FACTOR`
@@ -19,22 +19,15 @@ See Also
 
 References
 ----------
-.. [1]  **Mark D. Fairchild**,
-        *Refinement of the RLAB color space*,
-        *Color Research & Application, Volume 21, Issue 5, pages 338–346,
-        October 1996*,
-        DOI: http://dx.doi.org/10.1002/(SICI)1520-6378(199610)21:5<338::AID-COL3>3.0.CO;2-Z  # noqa
-        https://ritdml.rit.edu/bitstream/handle/1850/7857/MFairchildArticle12-06-1998.pdf  # noqa
-        (Last accessed 16 August 2014)
-.. [2]  **Mark D. Fairchild**, *Color Appearance Models, 3nd Edition*,
-        The Wiley-IS&T Series in Imaging Science and Technology,
-        published June 2013, ASIN: B00DAYO8E2,
-        locations 6019-6178.
+.. [1]  Fairchild, M. D. (1996). Refinement of the RLAB color space. Color
+        Research & Application, 21(5), 338–346.
+        doi:10.1002/(SICI)1520-6378(199610)21:5<338::AID-COL3>3.0.CO;2-Z
+.. [2]  Fairchild, M. D. (2013). The RLAB Model. In Color Appearance Models
+        (3rd ed., pp. 5563–5824). Wiley. ASIN:B00DAYO8E2
 """
 
 from __future__ import division, unicode_literals
 
-import math
 import numpy as np
 from collections import namedtuple
 
@@ -61,7 +54,7 @@ R_MATRIX = np.array(
      [0.3612, 0.6388, 0.0000],
      [0.0000, 0.0000, 1.0000]])
 """
-*RLAB* colour appearance model precomputed helper matrix.
+RLAB colour appearance model precomputed helper matrix.
 
 R_MATRIX : array_like, (3, 3)
 """
@@ -71,10 +64,10 @@ RLAB_VIEWING_CONDITIONS = CaseInsensitiveMapping(
      'Dim': 1 / 2.9,
      'Dark': 1 / 3.5})
 """
-Reference *RLAB* colour appearance model viewing conditions.
+Reference RLAB colour appearance model viewing conditions.
 
-RLAB_VIEWING_CONDITIONS : dict
-    ('Average', 'Dim', 'Dark')
+RLAB_VIEWING_CONDITIONS : CaseInsensitiveMapping
+    {'Average', 'Dim', 'Dark'}
 """
 
 RLAB_D_FACTOR = CaseInsensitiveMapping(
@@ -82,12 +75,12 @@ RLAB_D_FACTOR = CaseInsensitiveMapping(
      'Soft Copy Images': 0,
      'Projected Transparencies, Dark Room': 0.5})
 """
-*RLAB* colour appearance model *Discounting-the-Illuminant* factor values.
+RLAB colour appearance model *Discounting-the-Illuminant* factor values.
 
-RLAB_D_FACTOR : dict
-    ('Hard Copy Images',
+RLAB_D_FACTOR : CaseInsensitiveMapping
+    {'Hard Copy Images',
     'Soft Copy Images',
-    'Projected Transparencies, Dark Room')
+    'Projected Transparencies, Dark Room'}
 
 Aliases:
 
@@ -107,9 +100,9 @@ class RLAB_ReferenceSpecification(
     namedtuple('RLAB_ReferenceSpecification',
                ('LR', 'CR', 'hR', 'sR', 'HR', 'aR', 'bR'))):
     """
-    Defines the *RLAB* colour appearance model reference specification.
+    Defines the RLAB colour appearance model reference specification.
 
-    This specification has field names consistent with **Mark D. Fairchild**
+    This specification has field names consistent with Fairchild (2013)
     reference.
 
     Parameters
@@ -135,11 +128,11 @@ class RLAB_Specification(
     namedtuple('RLAB_Specification',
                ('J', 'C', 'h', 's', 'HC', 'a', 'b'))):
     """
-    Defines the *RLAB* colour appearance model specification.
+    Defines the RLAB colour appearance model specification.
 
     This specification has field names consistent with the remaining colour
-    appearance models in :mod:`colour.appearance` but diverge from
-    **Mark D. Fairchild** reference.
+    appearance models in :mod:`colour.appearance` but diverge from Fairchild
+    (2013) reference.
 
     Parameters
     ----------
@@ -186,7 +179,7 @@ def XYZ_to_RLAB(XYZ,
     Returns
     -------
     RLAB_Specification
-        *RLAB* colour appearance model specification.
+        RLAB colour appearance model specification.
 
     Warning
     -------
@@ -211,7 +204,6 @@ def XYZ_to_RLAB(XYZ,
     X, Y, Z = np.ravel(XYZ)
 
     # Converting to cone responses.
-    LMS = XYZ_to_rgb(XYZ)
     LMS_n = XYZ_to_rgb(XYZ_n)
 
     # Computing the :math:`A` matrix.
@@ -225,7 +217,7 @@ def XYZ_to_RLAB(XYZ,
         # *numeric* case.
         # Implementation as per reference.
         aR = np.diag(LMS_a_L)
-        XYZ_ref = R_MATRIX.dot(aR).dot(XYZ_TO_HPE_MATRIX).dot(XYZ)
+        XYZ_ref = np.dot(np.dot(np.dot(R_MATRIX, aR), XYZ_TO_HPE_MATRIX), XYZ)
     else:
         # *array_like* case.
         # Constructing huge multidimensional arrays might not be the best idea,
@@ -238,7 +230,8 @@ def XYZ_to_RLAB(XYZ,
         for layer in range(dimension):
             aR = np.diag(LMS_a_L[..., layer])
             XYZ_ref[..., layer] = (
-                R_MATRIX.dot(aR).dot(XYZ_TO_HPE_MATRIX).dot(XYZ[..., layer]))
+                np.dot(np.dot(np.dot(R_MATRIX, aR), XYZ_TO_HPE_MATRIX),
+                       XYZ[..., layer]))
 
     X_ref, Y_ref, Z_ref = XYZ_ref
 
@@ -254,7 +247,7 @@ def XYZ_to_RLAB(XYZ,
     # -------------------------------------------------------------------------
     # Computing the *hue* angle :math:`h^R`.
     # -------------------------------------------------------------------------
-    hR = math.degrees(np.arctan2(bR, aR)) % 360
+    hR = np.degrees(np.arctan2(bR, aR)) % 360
     # TODO: Implement hue composition computation.
 
     # -------------------------------------------------------------------------
