@@ -6,8 +6,7 @@ Illuminants Relative Spectral Power Distributions
 =================================================
 
 Defines *CIE* illuminants relative spectral power distributions for the
-*CIE 1931 2 Degree Standard Observer* and
-*CIE 1964 10 Degree Standard Observer*.
+*CIE 1931 2 Degree Standard Observer*.
 
 The *CIE* illuminants data is in the form of a *dict* of
 :class:`colour.colorimetry.spectrum.SpectralPowerDistribution` classes as
@@ -42,9 +41,10 @@ Notes
 
 References
 ----------
-.. [1]  http://files.cie.co.at/204.xls (Last accessed 24 February 2014)
-.. [2]  https://law.resource.org/pub/us/cfr/ibr/003/cie.15.2004.tables.xls
-        (Last accessed 24 February 2014)
+.. [1]  CIE. (n.d.). CIE Spectral Data. Retrieved from
+        http://files.cie.co.at/204.xls
+.. [2]  CIE. (n.d.). CIE 15:2004 Tables Data. Retrieved from
+        https://law.resource.org/pub/us/cfr/ibr/003/cie.15.2004.tables.xls
 """
 
 from __future__ import division, unicode_literals
@@ -3615,5 +3615,5 @@ ILLUMINANTS_RELATIVE_SPDS = CaseInsensitiveMapping(
 """
 *CIE* illuminants relative spectral power distributions.
 
-ILLUMINANTS_RELATIVE_SPDS : dict
+ILLUMINANTS_RELATIVE_SPDS : CaseInsensitiveMapping
 """
