@@ -3,14 +3,14 @@
 
 from __future__ import absolute_import
 
-from .cie import CIE_E, CIE_K
+from .cie import CIE_E, CIE_K, K_M, KP_M
 from .codata import (
     AVOGADRO_CONSTANT,
     BOLTZMANN_CONSTANT,
     LIGHT_SPEED,
     PLANCK_CONSTANT)
 
-__all__ = ['CIE_E', 'CIE_K']
+__all__ = ['CIE_E', 'CIE_K', 'K_M', 'KP_M']
 __all__ += ['AVOGADRO_CONSTANT',
             'BOLTZMANN_CONSTANT',
             'LIGHT_SPEED',
