@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Showcases *CIECAM02* colour appearance model computations.
+Showcases CIECAM02 colour appearance model computations.
 """
 
 import numpy as np
@@ -10,14 +10,14 @@ import numpy as np
 import colour
 from colour.utilities.verbose import message_box
 
-message_box('"CIECAM02" Colour Appearance Model Computations')
+message_box('CIECAM02 Colour Appearance Model Computations')
 
 XYZ = np.array([19.01, 20.00, 21.78])
 XYZ_w = np.array([95.05, 100.00, 108.88])
 L_A = 318.31
 Y_b = 20.0
 surround = colour.CIECAM02_VIEWING_CONDITIONS['Average']
-message_box(('Converting to "CIECAM02" colour appearance model specification '
+message_box(('Converting to CIECAM02 colour appearance model specification '
              'using given parameters:\n'
              '\n\tXYZ: {0}\n\tXYZ_w: {1}\n\tL_A: {2}\n\tY_b: {3}'
              '\n\tSurround: {4}'.format(XYZ, XYZ_w, L_A, Y_b, surround)))
