@@ -19,16 +19,30 @@ See Also
 
 References
 ----------
-.. [1]  http://www.oscars.org/science-technology/council/projects/aces.html
-        (Last accessed 24 February 2014)
-.. [2]  `Academy Color Encoding Specification (ACES)
-        <https://www.dropbox.com/sh/nt9z9m6utzvkc5m/AACBum5OdkLPCZ3d6trfVeU8a/ACES_v1.0.1.pdf>`_  # noqa
-        (Last accessed 24 February 2014)
+.. [1]  The Academy of Motion Picture Arts and Sciences, Science and
+        Technology Council, & Academy Color Encoding System (ACES) Project
+        Subcommittee. (n.d.). Academy Color Encoding System. Retrieved
+        February 24, 2014, from
+        http://www.oscars.org/science-technology/council/projects/aces.html
+.. [2]  The Academy of Motion Picture Arts and Sciences, Science and
+        Technology Council, & Academy Color Encoding System (ACES) Project
+        Subcommittee. (2011). Specification S-2008-001 - Academy Color
+        Encoding Specification ( ACES ), 1–33. Retrieved from
+        https://www.dropbox.com/sh/nt9z9m6utzvkc5m/AACBum5OdkLPCZ3d6trfVeU8a/ACES_v1.0.1.pdf  # noqa
+.. [3]  The Academy of Motion Picture Arts and Sciences, Science and
+        Technology Council, & Academy Color Encoding System (ACES) Project
+        Subcommittee. (2011). Logarithmic Encoding of ACES Data for use with
+        in Color Grading Systems, 1–11. Retrieved from
+        http://www.dropbox.com/sh/iwd09buudm3lfod/AAA-X1nVs_XLjWlzNhfhqiIna/ACESlog_v1.0.pdf  # noqa
+.. [4]  The Academy of Motion Picture Arts and Sciences, Science and
+        Technology Council, & Academy Color Encoding System (ACES) Project
+        Subcommittee. (2011). (2013). Specification S-2013-001 - ACESproxy, an
+        Integer Log Encoding of ACES Image Data, 1–13. Retrieved from
+        http://www.dropbox.com/sh/iwd09buudm3lfod/AAAsl8WskbNNAJXh1r0dPlp2a/ACESproxy_v1.1.pdf  # noqa
 """
 
 from __future__ import division, unicode_literals
 
-import math
 import numpy as np
 
 from colour.colorimetry import ILLUMINANTS
@@ -44,6 +58,7 @@ __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
 __all__ = ['ACES_RGB_PRIMARIES',
+           'ACES_RGB_ILLUMINANT',
            'ACES_RGB_WHITEPOINT',
            'ACES_RGB_TO_XYZ_MATRIX',
            'XYZ_TO_ACES_RGB_MATRIX',
@@ -72,16 +87,17 @@ ACES_RGB_PRIMARIES = np.array(
 *ACES RGB* colourspace primaries.
 
 ACES_RGB_PRIMARIES : ndarray, (3, 2)
+"""
 
-References
-----------
-.. [3]  `Academy Color Encoding Specification (ACES)
-        <https://www.dropbox.com/sh/nt9z9m6utzvkc5m/AACBum5OdkLPCZ3d6trfVeU8a/ACES_v1.0.1.pdf>`_  # noqa
-        4.1.2 Color space chromaticities (Last accessed 24 February 2014)
+ACES_RGB_ILLUMINANT = 'D60'
+"""
+*ACES RGB* colourspace whitepoint name as illuminant.
+
+ACES_RGB_ILLUMINANT : unicode
 """
 
 ACES_RGB_WHITEPOINT = ILLUMINANTS.get(
-    'CIE 1931 2 Degree Standard Observer').get('D60')
+    'CIE 1931 2 Degree Standard Observer').get(ACES_RGB_ILLUMINANT)
 """
 *ACES RGB* colourspace whitepoint.
 
@@ -96,12 +112,6 @@ ACES_RGB_TO_XYZ_MATRIX = np.array(
 *ACES RGB* colourspace to *CIE XYZ* colourspace matrix.
 
 ACES_RGB_TO_XYZ_MATRIX : array_like, (3, 3)
-
-References
-----------
-.. [4]  http://www.dropbox.com/sh/iwd09buudm3lfod/gyjDF-k7oC/ACES_v1.0.1.pdf:
-        4.1.4 Converting ACES RGB values to CIE XYZ values
-        (Last accessed 24 February 2014)
 """
 
 XYZ_TO_ACES_RGB_MATRIX = np.linalg.inv(ACES_RGB_TO_XYZ_MATRIX)
@@ -111,14 +121,51 @@ XYZ_TO_ACES_RGB_MATRIX = np.linalg.inv(ACES_RGB_TO_XYZ_MATRIX)
 XYZ_TO_ACES_RGB_MATRIX : array_like, (3, 3)
 """
 
-ACES_RGB_TRANSFER_FUNCTION = lambda x: x
+
+def _aces_rgb_transfer_function(value):
+    """
+    Defines the *ACES RGB* value colourspace transfer function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return value
+
+
+def _aces_rgb_inverse_transfer_function(value):
+    """
+    Defines the *ACES RGB* value colourspace inverse transfer function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return value
+
+
+ACES_RGB_TRANSFER_FUNCTION = _aces_rgb_transfer_function
 """
 Transfer function from linear to *ACES RGB* colourspace.
 
 ACES_RGB_TRANSFER_FUNCTION : object
 """
 
-ACES_RGB_INVERSE_TRANSFER_FUNCTION = lambda x: x
+ACES_RGB_INVERSE_TRANSFER_FUNCTION = _aces_rgb_inverse_transfer_function
 """
 Inverse transfer function from *ACES RGB* colourspace to linear.
 
@@ -129,6 +176,7 @@ ACES_RGB_COLOURSPACE = RGB_Colourspace(
     'ACES RGB',
     ACES_RGB_PRIMARIES,
     ACES_RGB_WHITEPOINT,
+    ACES_RGB_ILLUMINANT,
     ACES_RGB_TO_XYZ_MATRIX,
     XYZ_TO_ACES_RGB_MATRIX,
     ACES_RGB_TRANSFER_FUNCTION,
@@ -142,8 +190,8 @@ ACES_RGB_COLOURSPACE : RGB_Colourspace
 ACES_RGB_LOG_CONSTANTS = Structure(
     log_unity=32768,
     log_xperstop=2048,
-    denorm_trans=math.pow(2, -15),
-    denorm_fake0=math.pow(2, -16))
+    denorm_trans=np.power(2., -15),
+    denorm_fake0=np.power(2., -16))
 """
 *ACES RGB Log* colourspace constants.
 
@@ -174,12 +222,12 @@ def _aces_rgb_log_transfer_function(value, is_16_bit_integer=False):
     if value < ACES_RGB_LOG_CONSTANTS.denorm_trans:
         value = ACES_RGB_LOG_CONSTANTS.denorm_fake0 + (value / 2)
 
-    value = ((math.log10(value) / math.log10(2)) *
+    value = (np.log2(value) *
              ACES_RGB_LOG_CONSTANTS.log_xperstop +
              ACES_RGB_LOG_CONSTANTS.log_unity)
 
     if is_16_bit_integer:
-        value = min(math.floor(value) + 0.5, 65535)
+        value = min(np.floor(value) + 0.5, 65535)
 
     return value
 
@@ -199,7 +247,7 @@ def _aces_rgb_log_inverse_transfer_function(value):
         Companded value.
     """
 
-    value = (math.pow(2,
+    value = (np.power(2.,
                       (value - ACES_RGB_LOG_CONSTANTS.log_unity) /
                       ACES_RGB_LOG_CONSTANTS.log_xperstop))
     if value < ACES_RGB_LOG_CONSTANTS.denorm_trans:
@@ -227,6 +275,7 @@ ACES_RGB_LOG_COLOURSPACE = RGB_Colourspace(
     'ACES RGB Log',
     ACES_RGB_PRIMARIES,
     ACES_RGB_WHITEPOINT,
+    ACES_RGB_ILLUMINANT,
     ACES_RGB_TO_XYZ_MATRIX,
     XYZ_TO_ACES_RGB_MATRIX,
     ACES_RGB_LOG_TRANSFER_FUNCTION,
@@ -235,12 +284,6 @@ ACES_RGB_LOG_COLOURSPACE = RGB_Colourspace(
 *ACES RGB Log* colourspace.
 
 ACES_RGB_LOG_COLOURSPACE : RGB_Colourspace
-
-References
-----------
-.. [5]  `Logarithmic Encoding of ACES Data for use within Color Grading Systems
-        <http://www.dropbox.com/sh/iwd09buudm3lfod/AAA-X1nVs_XLjWlzNhfhqiIna/ACESlog_v1.0.pdf>`_  # noqa
-        (Last accessed 17 May 2014)
 """
 
 ACES_RGB_PROXY_10_CONSTANTS = Structure(
@@ -273,8 +316,8 @@ ACES_RGB_PROXY_CONSTANTS = CaseInsensitiveMapping(
 """
 Aggregated *ACES RGB Proxy* colourspace constants.
 
-ACES_RGB_PROXY_CONSTANTS : dict
-    ('10 Bit', '12 Bit')
+ACES_RGB_PROXY_CONSTANTS : CaseInsensitiveMapping
+    {'10 Bit', '12 Bit'}
 """
 
 
@@ -286,7 +329,8 @@ def _aces_rgb_proxy_transfer_function(value, bit_depth='10 Bit'):
     ----------
     value : numeric
         value.
-    bit_depth : unicode ('10 Bit', '12 Bit')
+    bit_depth : unicode, optional
+        {'10 Bit', '12 Bit'}
         *ACES RGB Proxy* bit depth.
 
     Returns
@@ -297,12 +341,11 @@ def _aces_rgb_proxy_transfer_function(value, bit_depth='10 Bit'):
 
     constants = ACES_RGB_PROXY_CONSTANTS.get(bit_depth)
 
+    float_2_cv = lambda x: max(constants.CV_min,
+                               min(constants.CV_max, round(x)))
     if value > 0:
-        return max(constants.CV_min,
-                   min(constants.CV_max,
-                       ((math.log10(value) / (math.log10(2)) -
-                         constants.mid_log_offset) * constants.steps_per_stop +
-                        constants.mid_CV_offset)) + 0.5)
+        return float_2_cv((np.log2(value) - constants.mid_log_offset) *
+                          constants.steps_per_stop + constants.mid_CV_offset)
     else:
         return constants.CV_min
 
@@ -315,7 +358,8 @@ def _aces_rgb_proxy_inverse_transfer_function(value, bit_depth='10 Bit'):
     ----------
     value : numeric
         value.
-    bit_depth : str ('10 Bit', '12 Bit')
+    bit_depth : unicode, optional
+        {'10 Bit', '12 Bit'}
         *ACES RGB Proxy* bit depth.
 
     Returns
@@ -326,37 +370,72 @@ def _aces_rgb_proxy_inverse_transfer_function(value, bit_depth='10 Bit'):
 
     constants = ACES_RGB_PROXY_CONSTANTS.get(bit_depth)
 
-    return math.pow(2,
-                    ((((value - constants.mid_CV_offset) /
-                       constants.steps_per_stop) + constants.mid_log_offset)))
+    return (2 ** (((value - constants.mid_CV_offset) /
+                   constants.steps_per_stop + constants.mid_log_offset)))
 
 
-ACES_RGB_PROXY_10_TRANSFER_FUNCTION = lambda x: (
-    _aces_rgb_proxy_transfer_function(x))
+ACES_RGB_PROXY_10_TRANSFER_FUNCTION = _aces_rgb_proxy_transfer_function
 """
 Transfer function from linear to *ACES RGB Proxy 10* colourspace.
 
 ACES_RGB_PROXY_10_TRANSFER_FUNCTION : object
 """
 
-ACES_RGB_PROXY_10_INVERSE_TRANSFER_FUNCTION = lambda x: (
-    _aces_rgb_proxy_inverse_transfer_function(x))
+ACES_RGB_PROXY_10_INVERSE_TRANSFER_FUNCTION = (
+    _aces_rgb_proxy_inverse_transfer_function)
 """
 Inverse transfer function from *ACES RGB Proxy 10* colourspace to linear.
 
 ACES_RGB_PROXY_10_INVERSE_TRANSFER_FUNCTION : object
 """
 
-ACES_RGB_PROXY_12_TRANSFER_FUNCTION = lambda x: (
-    _aces_rgb_proxy_transfer_function(x, bit_depth='12 Bit'))
+
+def _aces_rgb_proxy_12_transfer_function(value):
+    """
+    Defines the *ACES RGB Proxy 12* colourspace transfer function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return _aces_rgb_proxy_transfer_function(value, '12 Bit')
+
+
+def _aces_rgb_proxy_12_inverse_transfer_function(value):
+    """
+    Defines the *ACES RGB Proxy 12* colourspace inverse transfer function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return _aces_rgb_proxy_inverse_transfer_function(value, '12 Bit')
+
+
+ACES_RGB_PROXY_12_TRANSFER_FUNCTION = (
+    _aces_rgb_proxy_12_transfer_function)
 """
 Transfer function from linear to *ACES RGB Proxy 12* colourspace.
 
 ACES_RGB_PROXY_12_TRANSFER_FUNCTION : object
 """
 
-ACES_RGB_PROXY_12_INVERSE_TRANSFER_FUNCTION = lambda x: (
-    _aces_rgb_proxy_inverse_transfer_function(x, bit_depth='12 Bit'))
+ACES_RGB_PROXY_12_INVERSE_TRANSFER_FUNCTION = (
+    _aces_rgb_proxy_12_inverse_transfer_function)
 """
 Inverse transfer function from *ACES RGB Proxy 12* colourspace to linear.
 
@@ -367,6 +446,7 @@ ACES_RGB_PROXY_10_COLOURSPACE = RGB_Colourspace(
     'ACES RGB Proxy 10',
     ACES_RGB_PRIMARIES,
     ACES_RGB_WHITEPOINT,
+    ACES_RGB_ILLUMINANT,
     ACES_RGB_TO_XYZ_MATRIX,
     XYZ_TO_ACES_RGB_MATRIX,
     ACES_RGB_PROXY_10_TRANSFER_FUNCTION,
@@ -375,18 +455,13 @@ ACES_RGB_PROXY_10_COLOURSPACE = RGB_Colourspace(
 *ACES RGB Proxy 10* colourspace.
 
 ACES_RGB_PROXY_10_COLOURSPACE : RGB_Colourspace
-
-References
-----------
-.. [6]  `ACESproxy, an Integer Log Encoding of ACES Image Data
-        <http://www.dropbox.com/sh/iwd09buudm3lfod/AAAsl8WskbNNAJXh1r0dPlp2a/ACESproxy_v1.1.pdf>`_  # noqa
-        (Last accessed 17 May 2014)
 """
 
 ACES_RGB_PROXY_12_COLOURSPACE = RGB_Colourspace(
     'ACES RGB Proxy 12',
     ACES_RGB_PRIMARIES,
     ACES_RGB_WHITEPOINT,
+    ACES_RGB_ILLUMINANT,
     ACES_RGB_TO_XYZ_MATRIX,
     XYZ_TO_ACES_RGB_MATRIX,
     ACES_RGB_PROXY_12_TRANSFER_FUNCTION,
@@ -395,10 +470,4 @@ ACES_RGB_PROXY_12_COLOURSPACE = RGB_Colourspace(
 *ACES RGB Proxy 12* colourspace.
 
 ACES_RGB_PROXY_12_COLOURSPACE : RGB_Colourspace
-
-References
-----------
-.. [7]  `ACESproxy, an Integer Log Encoding of ACES Image Data
-        <http://www.dropbox.com/sh/iwd09buudm3lfod/AAAsl8WskbNNAJXh1r0dPlp2a/ACESproxy_v1.1.pdf>`_  # noqa
-        (Last accessed 17 May 2014)
 """
