@@ -16,14 +16,12 @@ See Also
 
 References
 ----------
-.. [1]  `Canon-Log_Transfer_Characteristic
-        <http://downloads.canon.com/CDLC/Canon-Log_Transfer_Characteristic_6-20-2012.pdf>`_  # noqa
-        (Last accessed 18 April 2014)
+.. [1]  Thorpe, L. (2012). CANON-LOG TRANSFER CHARACTERISTIC. Retrieved from
+        http://downloads.canon.com/CDLC/Canon-Log_Transfer_Characteristic_6-20-2012.pdf  # noqa
 """
 
 from __future__ import division, unicode_literals
 
-import math
 import numpy as np
 
 from colour.colorimetry import ILLUMINANTS
@@ -37,6 +35,7 @@ __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
 __all__ = ['C_LOG_PRIMARIES',
+           'C_LOG_ILLUMINANT',
            'C_LOG_WHITEPOINT',
            'C_LOG_TO_XYZ_MATRIX',
            'XYZ_TO_C_LOG_MATRIX',
@@ -54,8 +53,15 @@ C_LOG_PRIMARIES = np.array(
 C_LOG_PRIMARIES : ndarray, (3, 2)
 """
 
+C_LOG_ILLUMINANT = 'D65'
+"""
+*C-Log* colourspace whitepoint name as illuminant.
+
+C_LOG_ILLUMINANT : unicode
+"""
+
 C_LOG_WHITEPOINT = ILLUMINANTS.get(
-    'CIE 1931 2 Degree Standard Observer').get('D65')
+    'CIE 1931 2 Degree Standard Observer').get(C_LOG_ILLUMINANT)
 """
 *C-Log* colourspace whitepoint.
 
@@ -77,16 +83,53 @@ XYZ_TO_C_LOG_MATRIX = np.linalg.inv(C_LOG_TO_XYZ_MATRIX)
 XYZ_TO_C_LOG_MATRIX : array_like, (3, 3)
 """
 
-C_LOG_TRANSFER_FUNCTION = lambda x: (
-    0.529136 * math.log10(10.1596 * x + 1) + 0.0730597)
+
+def _c_log_transfer_function(value):
+    """
+    Defines the *C-Log* value colourspace transfer function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return 0.529136 * np.log10(10.1596 * value + 1) + 0.0730597
+
+
+def _c_log_inverse_transfer_function(value):
+    """
+    Defines the *C-Log* value colourspace inverse transfer
+    function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return -0.071622555735168 * (
+        1.3742747797867 - np.exp(1) ** (4.3515940948906 * value))
+
+
+C_LOG_TRANSFER_FUNCTION = _c_log_transfer_function
 """
 Transfer function from linear to *C-Log* colourspace.
 
 C_LOG_TRANSFER_FUNCTION : object
 """
 
-C_LOG_INVERSE_TRANSFER_FUNCTION = lambda x: (
-    -0.0716226 * (1.37427 - math.exp(1) ** (4.35159 * x)))
+C_LOG_INVERSE_TRANSFER_FUNCTION = _c_log_inverse_transfer_function
 """
 Inverse transfer function from *C-Log* colourspace to linear.
 
@@ -97,6 +140,7 @@ C_LOG_COLOURSPACE = RGB_Colourspace(
     'C-Log',
     C_LOG_PRIMARIES,
     C_LOG_WHITEPOINT,
+    C_LOG_ILLUMINANT,
     C_LOG_TO_XYZ_MATRIX,
     XYZ_TO_C_LOG_MATRIX,
     C_LOG_TRANSFER_FUNCTION,
