@@ -16,16 +16,17 @@ See Also
 
 References
 ----------
-.. [1]  `Understanding the HP DreamColor LP2480zx DCI-P3 Emulation Color Space
-        <http://www.hp.com/united-states/campaigns/workstations/pdfs/lp2480zx-dci--p3-emulation.pdf>`_  # noqa
-        (Last accessed 24 February 2014)
+.. [1]  Hewlett-Packard Development Company. (2009). Understanding the HP
+        DreamColor LP2480zx DCI-P3 Emulation Color Space. Retrieved from
+        http://www.hp.com/united-states/campaigns/workstations/pdfs/lp2480zx-dci--p3-emulation.pdf  # noqa
 """
 
 from __future__ import division, unicode_literals
 
 import numpy as np
 
-from colour.models import RGB_Colourspace
+from colour.colorimetry import ILLUMINANTS
+from colour.models import RGB_Colourspace, normalised_primary_matrix
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013 - 2014 - Colour Developers'
@@ -35,6 +36,7 @@ __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
 __all__ = ['DCI_P3_PRIMARIES',
+           'DCI_P3_ILLUMINANT',
            'DCI_P3_WHITEPOINT',
            'DCI_P3_TO_XYZ_MATRIX',
            'XYZ_TO_DCI_P3_MATRIX',
@@ -52,17 +54,31 @@ DCI_P3_PRIMARIES = np.array(
 DCI_P3_PRIMARIES : ndarray, (3, 2)
 """
 
-DCI_P3_WHITEPOINT = (0.314, 0.351)
+DCI_P3_ILLUMINANT = 'D65'
+"""
+*DCI-P3* colourspace whitepoint name as illuminant.
+
+DCI_P3_ILLUMINANT : unicode
+
+Notes
+-----
+-   We don't know which whitepoint DCI-P3 is officially using and are assuming
+    *CIE Illuminant D Series* *D65*. Hewlett-Packard Development Company
+    (2009) mentions *(0.314, 0.351)* in their emulation for the
+    *HP DreamColor LP2480zx Professional Display*.
+"""
+
+DCI_P3_WHITEPOINT = ILLUMINANTS.get(
+    'CIE 1931 2 Degree Standard Observer').get(DCI_P3_ILLUMINANT)
 """
 *DCI-P3* colourspace whitepoint.
 
 DCI_P3_WHITEPOINT : tuple
 """
 
-DCI_P3_TO_XYZ_MATRIX = np.array(
-    [[0.44516982, 0.27713441, 0.17228267],
-     [0.20949168, 0.72159525, 0.06891307],
-     [0, 0.04706056, 0.90735539]])
+DCI_P3_TO_XYZ_MATRIX = normalised_primary_matrix(
+    DCI_P3_PRIMARIES,
+    DCI_P3_WHITEPOINT)
 """
 *DCI-P3* colourspace to *CIE XYZ* colourspace matrix.
 
@@ -76,14 +92,51 @@ XYZ_TO_DCI_P3_MATRIX = np.linalg.inv(DCI_P3_TO_XYZ_MATRIX)
 XYZ_TO_DCI_P3_MATRIX : array_like, (3, 3)
 """
 
-DCI_P3_TRANSFER_FUNCTION = lambda x: x
+
+def _dci_p3_transfer_function(value):
+    """
+    Defines the *DCI-P3* value colourspace transfer function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return value
+
+
+def _dci_p3_inverse_transfer_function(value):
+    """
+    Defines the *DCI-P3* value colourspace inverse transfer function.
+
+    Parameters
+    ----------
+    value : numeric
+        value.
+
+    Returns
+    -------
+    numeric
+        Companded value.
+    """
+
+    return value
+
+
+DCI_P3_TRANSFER_FUNCTION = _dci_p3_transfer_function
 """
 Transfer function from linear to *DCI-P3* colourspace.
 
 DCI_P3_TRANSFER_FUNCTION : object
 """
 
-DCI_P3_INVERSE_TRANSFER_FUNCTION = lambda x: x
+DCI_P3_INVERSE_TRANSFER_FUNCTION = _dci_p3_inverse_transfer_function
 """
 Inverse transfer function from *DCI-P3* colourspace to linear.
 
@@ -94,6 +147,7 @@ DCI_P3_COLOURSPACE = RGB_Colourspace(
     'DCI-P3',
     DCI_P3_PRIMARIES,
     DCI_P3_WHITEPOINT,
+    DCI_P3_ILLUMINANT,
     DCI_P3_TO_XYZ_MATRIX,
     XYZ_TO_DCI_P3_MATRIX,
     DCI_P3_TRANSFER_FUNCTION,
