@@ -16,8 +16,8 @@ See Also
 
 References
 ----------
-.. [1]  http://www.cis.rit.edu/research/mcsl2/online/munsell.php
-.. [2]  http://www.cis.rit.edu/research/mcsl2/online/munsell_data/1929.dat
+.. [1]  Munsell Color Science. (n.d.). Munsell Colours Data. Retrieved August
+        20, 2014, from http://www.cis.rit.edu/research/mcsl2/online/munsell.php
 """
 
 from __future__ import division, unicode_literals
