@@ -18,15 +18,17 @@ See Also
 
 References
 ----------
-.. [1]  `On Rayleigh Optical Depth Calculations
-        <http://journals.ametsoc.org/doi/pdf/10.1175/1520-0426(1999)016%3C1854%3AORODC%3E2.0.CO%3B2>`_,  # noqa
-        DOI: http://dx.doi.org/10.1175/1520-0426(1999)016%3C1854:ORODC%3E2.0.CO;2  # noqa
-.. [2]  http://en.wikipedia.org/wiki/Rayleigh_scattering
+.. [1]  Bodhaine, B. A., Wood, N. B., Dutton, E. G., & Slusser, J. R. (1999).
+        On Rayleigh optical depth calculations. Journal of Atmospheric …,
+        16(11 PART 2), 1854–1861.
+        doi:10.1175/1520-0426(1999)016%3C1854:ORODC%3E2.0.CO;2
+.. [2]  Wikipedia. (n.d.). Rayleigh scattering. Retrieved September 23, 2014,
+        from http://en.wikipedia.org/wiki/Rayleigh_scattering
 """
 
 from __future__ import division, unicode_literals
 
-import math
+import numpy as np
 
 from colour.colorimetry import (
     DEFAULT_SPECTRAL_SHAPE,
@@ -45,19 +47,19 @@ __all__ = ['STANDARD_AIR_TEMPERATURE',
            'AVERAGE_PRESSURE_MEAN_SEA_LEVEL',
            'DEFAULT_LATITUDE',
            'DEFAULT_ALTITUDE',
-           'air_refraction_index_penndorf1957',
-           'air_refraction_index_edlen1966',
-           'air_refraction_index_peck1972',
-           'air_refraction_index_bodhaine1999',
+           'air_refraction_index_Penndorf1957',
+           'air_refraction_index_Edlen1966',
+           'air_refraction_index_Peck1972',
+           'air_refraction_index_Bodhaine1999',
            'N2_depolarisation',
            'O2_depolarisation',
-           'F_air_penndorf1957',
-           'F_air_young1981',
-           'F_air_bates1984',
-           'F_air_bodhaine1999',
+           'F_air_Penndorf1957',
+           'F_air_Young1981',
+           'F_air_Bates1984',
+           'F_air_Bodhaine1999',
            'molecular_density',
            'mean_molecular_weights',
-           'gravity_list1968',
+           'gravity_List1968',
            'scattering_cross_section',
            'rayleigh_optical_depth',
            'rayleigh_scattering']
@@ -98,10 +100,10 @@ DEFAULT_ALTITUDE : numeric
 """
 
 
-def air_refraction_index_penndorf1957(wavelength, *args):
+def air_refraction_index_Penndorf1957(wavelength, *args):
     """
     Returns the air refraction index :math:`n_s` from given wavelength
-    :math:`\lambda` in  micrometers (:math:`\mu m`) using *Penndorf (1957)*
+    :math:`\lambda` in  micrometers (:math:`\mu m`) using Penndorf (1957)
     method.
 
     Parameters
@@ -118,12 +120,12 @@ def air_refraction_index_penndorf1957(wavelength, *args):
 
     See Also
     --------
-    air_refraction_index_edlen1966, air_refraction_index_peck1972,
-    air_refraction_index_bodhaine1999
+    air_refraction_index_Edlen1966, air_refraction_index_Peck1972,
+    air_refraction_index_Bodhaine1999
 
     Examples
     --------
-    >>> air_refraction_index_penndorf1957(0.555)  # doctest: +ELLIPSIS
+    >>> air_refraction_index_Penndorf1957(0.555)  # doctest: +ELLIPSIS
     1.0002777...
     """
 
@@ -133,10 +135,10 @@ def air_refraction_index_penndorf1957(wavelength, *args):
     return n
 
 
-def air_refraction_index_edlen1966(wavelength, *args):
+def air_refraction_index_Edlen1966(wavelength, *args):
     """
     Returns the air refraction index :math:`n_s` from given wavelength
-    :math:`\lambda` in micrometers (:math:`\mu m`) using *Edlen (1966)* method.
+    :math:`\lambda` in micrometers (:math:`\mu m`) using Edlen (1966) method.
 
     Parameters
     ----------
@@ -152,12 +154,12 @@ def air_refraction_index_edlen1966(wavelength, *args):
 
     See Also
     --------
-    air_refraction_index_penndorf1957, air_refraction_index_peck1972,
-    air_refraction_index_bodhaine1999
+    air_refraction_index_Penndorf1957, air_refraction_index_Peck1972,
+    air_refraction_index_Bodhaine1999
 
     Examples
     --------
-    >>> air_refraction_index_edlen1966(0.555)  # doctest: +ELLIPSIS
+    >>> air_refraction_index_Edlen1966(0.555)  # doctest: +ELLIPSIS
     1.0002777...
     """
 
@@ -167,11 +169,11 @@ def air_refraction_index_edlen1966(wavelength, *args):
     return n
 
 
-def air_refraction_index_peck1972(wavelength, *args):
+def air_refraction_index_Peck1972(wavelength, *args):
     """
     Returns the air refraction index :math:`n_s` from given wavelength
     :math:`\lambda` in micrometers (:math:`\mu m`) using
-    *Peck and Reeder (1972)* method.
+    Peck and Reeder (1972) method.
 
     Parameters
     ----------
@@ -187,12 +189,12 @@ def air_refraction_index_peck1972(wavelength, *args):
 
     See Also
     --------
-    air_refraction_index_penndorf1957, air_refraction_index_edlen1966,
-    air_refraction_index_bodhaine1999
+    air_refraction_index_Penndorf1957, air_refraction_index_Edlen1966,
+    air_refraction_index_Bodhaine1999
 
     Examples
     --------
-    >>> air_refraction_index_peck1972(0.555)  # doctest: +ELLIPSIS
+    >>> air_refraction_index_Peck1972(0.555)  # doctest: +ELLIPSIS
     1.0002777...
     """
 
@@ -203,13 +205,13 @@ def air_refraction_index_peck1972(wavelength, *args):
     return n
 
 
-def air_refraction_index_bodhaine1999(
+def air_refraction_index_Bodhaine1999(
         wavelength,
         CO2_concentration=STANDARD_CO2_CONCENTRATION):
     """
     Returns the air refraction index :math:`n_s` from given wavelength
     :math:`\lambda` in micrometers (:math:`\mu m`) using
-    *Bodhaine, Wood, Dutton and Slusser (1999)* method.
+    Bodhaine, Wood, Dutton and Slusser (1999) method.
 
     Parameters
     ----------
@@ -225,19 +227,19 @@ def air_refraction_index_bodhaine1999(
 
     See Also
     --------
-    air_refraction_index_penndorf1957, air_refraction_index_edlen1966,
-    air_refraction_index_peck1972
+    air_refraction_index_Penndorf1957, air_refraction_index_Edlen1966,
+    air_refraction_index_Peck1972
 
     Examples
     --------
-    >>> air_refraction_index_bodhaine1999(0.555)  # doctest: +ELLIPSIS
+    >>> air_refraction_index_Bodhaine1999(0.555)  # doctest: +ELLIPSIS
     1.0002777...
     """
 
     wl = wavelength
     CCO2 = CO2_concentration
     n = ((1 + 0.54 * ((CCO2 * 1e-6) - 300e-6)) *
-         (air_refraction_index_peck1972(wl) - 1) + 1)
+         (air_refraction_index_Peck1972(wl) - 1) + 1)
     return n
 
 
@@ -296,10 +298,10 @@ def O2_depolarisation(wavelength):
     return O2
 
 
-def F_air_penndorf1957(*args):
+def F_air_Penndorf1957(*args):
     """
     Returns :math:`(6+3_p)/(6-7_p)`, the depolarisation term :math:`F(air)` or
-    *King Factor* using *Penndorf (1957)* method.
+    *King Factor* using Penndorf (1957) method.
 
     Parameters
     ----------
@@ -313,7 +315,7 @@ def F_air_penndorf1957(*args):
 
     See Also
     --------
-    F_air_young1981, F_air_bates1984, F_air_bodhaine1999
+    F_air_Young1981, F_air_Bates1984, F_air_Bodhaine1999
 
     Notes
     -----
@@ -323,17 +325,17 @@ def F_air_penndorf1957(*args):
 
     Examples
     --------
-    >>> F_air_penndorf1957(0.555)
+    >>> F_air_Penndorf1957(0.555)
     1.0608
     """
 
     return 1.0608
 
 
-def F_air_young1981(*args):
+def F_air_Young1981(*args):
     """
     Returns :math:`(6+3_p)/(6-7_p)`, the depolarisation term :math:`F(air)` or
-    *King Factor* using *Young (1981)* method.
+    *King Factor* using Young (1981) method.
 
     Parameters
     ----------
@@ -347,7 +349,7 @@ def F_air_young1981(*args):
 
     See Also
     --------
-    F_air_penndorf1957, F_air_bates1984, F_air_bodhaine1999
+    F_air_Penndorf1957, F_air_Bates1984, F_air_Bodhaine1999
 
     Notes
     -----
@@ -357,18 +359,18 @@ def F_air_young1981(*args):
 
     Examples
     --------
-    >>> F_air_young1981(0.555)
+    >>> F_air_Young1981(0.555)
     1.048
     """
 
     return 1.0480
 
 
-def F_air_bates1984(wavelength):
+def F_air_Bates1984(wavelength):
     """
     Returns :math:`(6+3_p)/(6-7_p)`, the depolarisation term :math:`F(air)` or
     *King Factor* as function of wavelength :math:`\lambda` in micrometers
-    (:math:`\mu m`) using *Bates (1984)* method.
+    (:math:`\mu m`) using Bates (1984) method.
 
     Parameters
     ----------
@@ -382,11 +384,11 @@ def F_air_bates1984(wavelength):
 
     See Also
     --------
-    F_air_penndorf1957, F_air_young1981, F_air_bodhaine1999
+    F_air_Penndorf1957, F_air_Young1981, F_air_Bodhaine1999
 
     Examples
     --------
-    >>> F_air_bates1984(0.555)  # doctest: +ELLIPSIS
+    >>> F_air_Bates1984(0.555)  # doctest: +ELLIPSIS
     1.0481535...
     """
 
@@ -402,13 +404,13 @@ def F_air_bates1984(wavelength):
     return F_air
 
 
-def F_air_bodhaine1999(wavelength,
+def F_air_Bodhaine1999(wavelength,
                        CO2_concentration=STANDARD_CO2_CONCENTRATION):
     """
     Returns :math:`(6+3_p)/(6-7_p)`, the depolarisation term :math:`F(air)` or
     *King Factor* as function of wavelength :math:`\lambda` in micrometers
     (:math:`\mu m`) and :math:`CO_2` concentration in parts per million (ppm)
-    using *Bodhaine, Wood, Dutton and Slusser (1999)* method.
+    using Bodhaine, Wood, Dutton and Slusser (1999) method.
 
     Parameters
     ----------
@@ -424,11 +426,11 @@ def F_air_bodhaine1999(wavelength,
 
     See Also
     --------
-    F_air_penndorf1957, F_air_young1981, F_air_bates1984
+    F_air_Penndorf1957, F_air_Young1981, F_air_Bates1984
 
     Examples
     --------
-    >>> F_air_bodhaine1999(0.555)  # doctest: +ELLIPSIS
+    >>> F_air_Bodhaine1999(0.555)  # doctest: +ELLIPSIS
     1.1246916...
     """
 
@@ -508,11 +510,11 @@ def mean_molecular_weights(CO2_concentration=STANDARD_CO2_CONCENTRATION):
     return m_a
 
 
-def gravity_list1968(latitude=DEFAULT_LATITUDE, altitude=DEFAULT_ALTITUDE):
+def gravity_List1968(latitude=DEFAULT_LATITUDE, altitude=DEFAULT_ALTITUDE):
     """
     Returns the gravity :math:`g` in :math:`cm/s_2` (gal) representative of the
     mass-weighted column of air molecules above the site of given latitude and
-    altitude using *List (1968)* method.
+    altitude using List (1968) method.
 
     Parameters
     ----------
@@ -528,18 +530,18 @@ def gravity_list1968(latitude=DEFAULT_LATITUDE, altitude=DEFAULT_ALTITUDE):
 
     Examples
     --------
-    >>> gravity_list1968()  # doctest: +ELLIPSIS
+    >>> gravity_List1968()  # doctest: +ELLIPSIS
     978.0356070...
-    >>> gravity_list1968(0, 1500)  # doctest: +ELLIPSIS
+    >>> gravity_List1968(0, 1500)  # doctest: +ELLIPSIS
     977.5726106...
 
     Gravity :math:`g` for Paris:
 
-    >>> gravity_list1968(48.8567, 35)  # doctest: +ELLIPSIS
+    >>> gravity_List1968(48.8567, 35)  # doctest: +ELLIPSIS
     980.9524178...
     """
 
-    cos2phi = math.cos(2 * math.radians(latitude))
+    cos2phi = np.cos(2 * np.radians(latitude))
 
     # Sea level acceleration of gravity.
     g0 = 980.6160 * (1 - 0.0026373 * cos2phi + 0.0000059 * cos2phi ** 2)
@@ -554,13 +556,13 @@ def scattering_cross_section(wavelength,
                              CO2_concentration=STANDARD_CO2_CONCENTRATION,
                              temperature=STANDARD_AIR_TEMPERATURE,
                              avogadro_constant=AVOGADRO_CONSTANT,
-                             n_s=air_refraction_index_bodhaine1999,
-                             F_air=F_air_bodhaine1999):
+                             n_s=air_refraction_index_Bodhaine1999,
+                             F_air=F_air_Bodhaine1999):
     """
     Returns the scattering cross section per molecule :math:`\sigma` of dry air
     as function of wavelength :math:`\lambda` in centimeters (cm) using given
     :math:`CO_2` concentration in parts per million (ppm) and temperature
-    :math:`T[K]` in kelvin degrees following *Van de Hulst (1957)* method.
+    :math:`T[K]` in kelvin degrees following Van de Hulst (1957) method.
 
     Parameters
     ----------
@@ -601,7 +603,7 @@ def scattering_cross_section(wavelength,
     N_s = molecular_density(temperature, avogadro_constant)
     F_air = F_air(wl_micrometers, CO2_concentration)
 
-    sigma = (24 * math.pi ** 3 * (n_s ** 2 - 1) ** 2 /
+    sigma = (24 * np.pi ** 3 * (n_s ** 2 - 1) ** 2 /
              (wl ** 4 * N_s ** 2 * (n_s ** 2 + 2) ** 2))
     sigma *= F_air
 
@@ -615,8 +617,8 @@ def rayleigh_optical_depth(wavelength,
                            latitude=DEFAULT_LATITUDE,
                            altitude=DEFAULT_ALTITUDE,
                            avogadro_constant=AVOGADRO_CONSTANT,
-                           n_s=air_refraction_index_bodhaine1999,
-                           F_air=F_air_bodhaine1999):
+                           n_s=air_refraction_index_Bodhaine1999,
+                           F_air=F_air_Bodhaine1999):
     """
     Returns the rayleigh optical depth :math:`T_r(\lambda)` as function of
     wavelength :math:`\lambda` in centimeters (cm).
@@ -671,7 +673,7 @@ def rayleigh_optical_depth(wavelength,
     # Conversion from pascal to dyne/cm2.
     P = pressure * 10
     m_a = mean_molecular_weights(CO2_c)
-    g = gravity_list1968(latitude, altitude)
+    g = gravity_List1968(latitude, altitude)
 
     T_R = sigma * (P * avogadro_constant) / (m_a * g)
 
@@ -688,8 +690,8 @@ def rayleigh_scattering_spd(shape=DEFAULT_SPECTRAL_SHAPE,
                             latitude=DEFAULT_LATITUDE,
                             altitude=DEFAULT_ALTITUDE,
                             avogadro_constant=AVOGADRO_CONSTANT,
-                            n_s=air_refraction_index_bodhaine1999,
-                            F_air=F_air_bodhaine1999):
+                            n_s=air_refraction_index_Bodhaine1999,
+                            F_air=F_air_Bodhaine1999):
     """
     Returns the rayleigh spectral power distribution for given spectral shape.
 
