@@ -36,11 +36,12 @@ from colour.models import (
     Luv_uv_to_xy,
     XYZ_to_sRGB)
 from colour.plotting import (
+    DEFAULT_FIGURE_WIDTH,
     PLOTTING_RESOURCES_DIRECTORY,
-    aspect,
-    bounding_box,
+    canvas,
+    decorate,
+    boundaries,
     display,
-    figure_size,
     get_cmfs)
 
 __author__ = 'Colour Developers'
@@ -58,7 +59,6 @@ __all__ = ['CIE_1931_chromaticity_diagram_colours_plot',
            'CIE_1976_UCS_chromaticity_diagram_plot']
 
 
-@figure_size((32, 32))
 def CIE_1931_chromaticity_diagram_colours_plot(
         surface=1.25,
         spacing=0.00075,
@@ -89,16 +89,19 @@ def CIE_1931_chromaticity_diagram_colours_plot(
     True
     """
 
-    cmfs, name = get_cmfs(cmfs), cmfs
+    settings = {'figure_size': (32, 32)}
+    settings.update(kwargs)
+
+    canvas(**settings)
+
+    cmfs = get_cmfs(cmfs)
 
     illuminant = ILLUMINANTS.get(
         'CIE 1931 2 Degree Standard Observer').get('E')
 
     XYZs = [value for key, value in cmfs]
 
-    x, y = tuple(zip(*([XYZ_to_xy(x) for x in XYZs])))
-
-    path = matplotlib.path.Path(tuple(zip(x, y)))
+    path = matplotlib.path.Path([XYZ_to_xy(x) for x in XYZs])
     x_dot, y_dot, colours = [], [], []
     for i in np.arange(0, 1, spacing):
         for j in np.arange(0, 1, spacing):
@@ -113,19 +116,19 @@ def CIE_1931_chromaticity_diagram_colours_plot(
 
     pylab.scatter(x_dot, y_dot, color=colours, s=surface)
 
-    settings = {'no_ticks': True,
-                'bounding_box': [0, 1, 0, 1],
-                'bbox_inches': 'tight',
-                'pad_inches': 0}
+    settings.update({
+        'no_ticks': True,
+        'bounding_box': [0, 1, 0, 1],
+        'bbox_inches': 'tight',
+        'pad_inches': 0})
     settings.update(kwargs)
 
-    bounding_box(**settings)
-    aspect(**settings)
+    boundaries(**settings)
+    decorate(**settings)
 
     return display(**settings)
 
 
-@figure_size((8, 8))
 def CIE_1931_chromaticity_diagram_plot(
         cmfs='CIE 1931 2 Degree Standard Observer', **kwargs):
     """
@@ -150,30 +153,34 @@ def CIE_1931_chromaticity_diagram_plot(
 
     """
 
-    cmfs, name = get_cmfs(cmfs), cmfs
+    settings = {'figure_size': (DEFAULT_FIGURE_WIDTH, DEFAULT_FIGURE_WIDTH)}
+    settings.update(kwargs)
+
+    canvas(**settings)
+
+    cmfs = get_cmfs(cmfs)
 
     image = matplotlib.image.imread(
         os.path.join(PLOTTING_RESOURCES_DIRECTORY,
-                     'CIE_1931_Chromaticity_Diagram_{0}_Small.png'.format(
+                     'CIE_1931_Chromaticity_Diagram_{0}_Large.png'.format(
                          cmfs.name.replace(' ', '_'))))
     pylab.imshow(image, interpolation='nearest', extent=(0, 1, 0, 1))
 
     labels = (
-        [390, 460, 470, 480, 490, 500, 510, 520, 540, 560, 580, 600, 620,
-         700])
+        [390, 460, 470, 480, 490, 500, 510, 520, 540, 560, 580, 600, 620, 700])
 
     wavelengths = cmfs.wavelengths
     equal_energy = np.array([1 / 3] * 2)
 
-    XYZs = [value for key, value in cmfs]
+    xy = np.array([XYZ_to_xy(XYZ) for XYZ in cmfs.values])
 
-    x, y = tuple(zip(*([XYZ_to_xy(x) for x in XYZs])))
+    wavelengths_chromaticity_coordinates = dict(tuple(zip(wavelengths, xy)))
 
-    wavelengths_chromaticity_coordinates = dict(
-        tuple(zip(wavelengths, tuple(zip(x, y)))))
-
-    pylab.plot(x, y, color='black', linewidth=2)
-    pylab.plot((x[-1], x[0]), (y[-1], y[0]), color='black', linewidth=2)
+    pylab.plot(xy[:, 0], xy[:, 1], color='black', linewidth=2)
+    pylab.plot((xy[-1][0], xy[0][0]),
+               (xy[-1][1], xy[0][1]),
+               color='black',
+               linewidth=2)
 
     for label in labels:
         x, y = wavelengths_chromaticity_coordinates.get(label)
@@ -214,8 +221,8 @@ def CIE_1931_chromaticity_diagram_plot(
                    va='center',
                    fontdict={'size': 'small'})
 
-    settings = {
-        'title': 'CIE 1931 Chromaticity Diagram - {0}'.format(name),
+    settings.update({
+        'title': 'CIE 1931 Chromaticity Diagram - {0}'.format(cmfs.title),
         'x_label': 'CIE x',
         'y_label': 'CIE y',
         'x_ticker': True,
@@ -223,16 +230,15 @@ def CIE_1931_chromaticity_diagram_plot(
         'grid': True,
         'bounding_box': [-0.1, 0.9, -0.1, 0.9],
         'bbox_inches': 'tight',
-        'pad_inches': 0}
+        'pad_inches': 0})
     settings.update(kwargs)
 
-    bounding_box(**settings)
-    aspect(**settings)
+    boundaries(**settings)
+    decorate(**settings)
 
     return display(**settings)
 
 
-@figure_size((32, 32))
 def CIE_1960_UCS_chromaticity_diagram_colours_plot(
         surface=1.25,
         spacing=0.00075,
@@ -263,16 +269,19 @@ def CIE_1960_UCS_chromaticity_diagram_colours_plot(
     True
     """
 
-    cmfs, name = get_cmfs(cmfs), cmfs
+    settings = {'figure_size': (32, 32)}
+    settings.update(kwargs)
+
+    canvas(**settings)
+
+    cmfs = get_cmfs(cmfs)
 
     illuminant = ILLUMINANTS.get(
         'CIE 1931 2 Degree Standard Observer').get('E')
 
-    UVWs = [XYZ_to_UCS(value) for key, value in cmfs]
+    uv = np.array([UCS_to_uv(XYZ_to_UCS(XYZ)) for XYZ in cmfs.values])
 
-    u, v = tuple(zip(*([UCS_to_uv(x) for x in UVWs])))
-
-    path = matplotlib.path.Path(tuple(zip(u, v)))
+    path = matplotlib.path.Path(uv)
     x_dot, y_dot, colours = [], [], []
     for i in np.arange(0, 1, spacing):
         for j in np.arange(0, 1, spacing):
@@ -287,19 +296,19 @@ def CIE_1960_UCS_chromaticity_diagram_colours_plot(
 
     pylab.scatter(x_dot, y_dot, color=colours, s=surface)
 
-    settings = {'no_ticks': True,
-                'bounding_box': [0, 1, 0, 1],
-                'bbox_inches': 'tight',
-                'pad_inches': 0}
+    settings.update({
+        'no_ticks': True,
+        'bounding_box': [0, 1, 0, 1],
+        'bbox_inches': 'tight',
+        'pad_inches': 0})
     settings.update(kwargs)
 
-    bounding_box(**settings)
-    aspect(**settings)
+    boundaries(**settings)
+    decorate(**settings)
 
     return display(**settings)
 
 
-@figure_size((8, 8))
 def CIE_1960_UCS_chromaticity_diagram_plot(
         cmfs='CIE 1931 2 Degree Standard Observer', **kwargs):
     """
@@ -323,11 +332,16 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
     True
     """
 
-    cmfs, name = get_cmfs(cmfs), cmfs
+    settings = {'figure_size': (DEFAULT_FIGURE_WIDTH, DEFAULT_FIGURE_WIDTH)}
+    settings.update(kwargs)
+
+    canvas(**settings)
+
+    cmfs = get_cmfs(cmfs)
 
     image = matplotlib.image.imread(
         os.path.join(PLOTTING_RESOURCES_DIRECTORY,
-                     'CIE_1960_UCS_Chromaticity_Diagram_{0}_Small.png'.format(
+                     'CIE_1960_UCS_Chromaticity_Diagram_{0}_Large.png'.format(
                          cmfs.name.replace(' ', '_'))))
     pylab.imshow(image, interpolation='nearest', extent=(0, 1, 0, 1))
 
@@ -337,15 +351,15 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
     wavelengths = cmfs.wavelengths
     equal_energy = np.array([1 / 3] * 2)
 
-    UVWs = [XYZ_to_UCS(value) for key, value in cmfs]
+    uv = np.array([UCS_to_uv(XYZ_to_UCS(XYZ)) for XYZ in cmfs.values])
 
-    u, v = tuple(zip(*([UCS_to_uv(x) for x in UVWs])))
+    wavelengths_chromaticity_coordinates = dict(tuple(zip(wavelengths, uv)))
 
-    wavelengths_chromaticity_coordinates = dict(
-        tuple(zip(wavelengths, tuple(zip(u, v)))))
-
-    pylab.plot(u, v, color='black', linewidth=2)
-    pylab.plot((u[-1], u[0]), (v[-1], v[0]), color='black', linewidth=2)
+    pylab.plot(uv[:, 0], uv[:, 1], color='black', linewidth=2)
+    pylab.plot((uv[-1][0], uv[0][0]),
+               (uv[-1][1], uv[0][1]),
+               color='black',
+               linewidth=2)
 
     for label in labels:
         u, v = wavelengths_chromaticity_coordinates.get(label)
@@ -386,8 +400,8 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
                    va='center',
                    fontdict={'size': 'small'})
 
-    settings = {
-        'title': 'CIE 1960 UCS Chromaticity Diagram - {0}'.format(name),
+    settings.update({
+        'title': 'CIE 1960 UCS Chromaticity Diagram - {0}'.format(cmfs.title),
         'x_label': 'CIE u',
         'y_label': 'CIE v',
         'x_ticker': True,
@@ -395,16 +409,15 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
         'grid': True,
         'bounding_box': [-0.075, 0.675, -0.15, 0.6],
         'bbox_inches': 'tight',
-        'pad_inches': 0}
+        'pad_inches': 0})
     settings.update(kwargs)
 
-    bounding_box(**settings)
-    aspect(**settings)
+    boundaries(**settings)
+    decorate(**settings)
 
     return display(**settings)
 
 
-@figure_size((32, 32))
 def CIE_1976_UCS_chromaticity_diagram_colours_plot(
         surface=1.25,
         spacing=0.00075,
@@ -435,16 +448,20 @@ def CIE_1976_UCS_chromaticity_diagram_colours_plot(
     True
     """
 
-    cmfs, name = get_cmfs(cmfs), cmfs
+    settings = {'figure_size': (32, 32)}
+    settings.update(kwargs)
+
+    canvas(**settings)
+
+    cmfs = get_cmfs(cmfs)
 
     illuminant = ILLUMINANTS.get(
         'CIE 1931 2 Degree Standard Observer').get('D50')
 
-    Luvs = [XYZ_to_Luv(value, illuminant) for key, value in cmfs]
+    uv = np.array([Luv_to_uv(XYZ_to_Luv(XYZ, illuminant))
+                   for XYZ in cmfs.values])
 
-    u, v = tuple(zip(*([Luv_to_uv(x) for x in Luvs])))
-
-    path = matplotlib.path.Path(tuple(zip(u, v)))
+    path = matplotlib.path.Path(uv)
     x_dot, y_dot, colours = [], [], []
     for i in np.arange(0, 1, spacing):
         for j in np.arange(0, 1, spacing):
@@ -459,19 +476,19 @@ def CIE_1976_UCS_chromaticity_diagram_colours_plot(
 
     pylab.scatter(x_dot, y_dot, color=colours, s=surface)
 
-    settings = {'no_ticks': True,
-                'bounding_box': [0, 1, 0, 1],
-                'bbox_inches': 'tight',
-                'pad_inches': 0}
+    settings.update({
+        'no_ticks': True,
+        'bounding_box': [0, 1, 0, 1],
+        'bbox_inches': 'tight',
+        'pad_inches': 0})
     settings.update(kwargs)
 
-    bounding_box(**settings)
-    aspect(**settings)
+    boundaries(**settings)
+    decorate(**settings)
 
     return display(**settings)
 
 
-@figure_size((8, 8))
 def CIE_1976_UCS_chromaticity_diagram_plot(
         cmfs='CIE 1931 2 Degree Standard Observer', **kwargs):
     """
@@ -495,11 +512,16 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
     True
     """
 
-    cmfs, name = get_cmfs(cmfs), cmfs
+    settings = {'figure_size': (DEFAULT_FIGURE_WIDTH, DEFAULT_FIGURE_WIDTH)}
+    settings.update(kwargs)
+
+    canvas(**settings)
+
+    cmfs = get_cmfs(cmfs)
 
     image = matplotlib.image.imread(
         os.path.join(PLOTTING_RESOURCES_DIRECTORY,
-                     'CIE_1976_UCS_Chromaticity_Diagram_{0}_Small.png'.format(
+                     'CIE_1976_UCS_Chromaticity_Diagram_{0}_Large.png'.format(
                          cmfs.name.replace(' ', '_'))))
     pylab.imshow(image, interpolation='nearest', extent=(0, 1, 0, 1))
 
@@ -512,15 +534,16 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
     illuminant = ILLUMINANTS.get(
         'CIE 1931 2 Degree Standard Observer').get('D50')
 
-    Luvs = [XYZ_to_Luv(value, illuminant) for key, value in cmfs]
+    uv = np.array([Luv_to_uv(XYZ_to_Luv(XYZ, illuminant))
+                   for XYZ in cmfs.values])
 
-    u, v = tuple(zip(*([Luv_to_uv(x) for x in Luvs])))
+    wavelengths_chromaticity_coordinates = dict(zip(wavelengths, uv))
 
-    wavelengths_chromaticity_coordinates = dict(zip(wavelengths,
-                                                    tuple(zip(u, v))))
-
-    pylab.plot(u, v, color='black', linewidth=2)
-    pylab.plot((u[-1], u[0]), (v[-1], v[0]), color='black', linewidth=2)
+    pylab.plot(uv[:, 0], uv[:, 1], color='black', linewidth=2)
+    pylab.plot((uv[-1][0], uv[0][0]),
+               (uv[-1][1], uv[0][1]),
+               color='black',
+               linewidth=2)
 
     for label in labels:
         u, v = wavelengths_chromaticity_coordinates.get(label)
@@ -561,19 +584,19 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
                    va='center',
                    fontdict={'size': 'small'})
 
-    settings = {
-        'title': 'CIE 1976 UCS Chromaticity Diagram - {0}'.format(name),
-        'x_label': 'CIE u"',
-        'y_label': 'CIE v"',
+    settings.update({
+        'title': 'CIE 1976 UCS Chromaticity Diagram - {0}'.format(cmfs.title),
+        'x_label': 'CIE u\'',
+        'y_label': 'CIE v\'',
         'x_ticker': True,
         'y_ticker': True,
         'grid': True,
         'bounding_box': [-0.1, .7, -.1, .7],
         'bbox_inches': 'tight',
-        'pad_inches': 0}
+        'pad_inches': 0})
     settings.update(kwargs)
 
-    bounding_box(**settings)
-    aspect(**settings)
+    boundaries(**settings)
+    decorate(**settings)
 
     return display(**settings)
