@@ -3,10 +3,10 @@
 
 from __future__ import absolute_import
 
-from .common import is_scipy_installed, is_string
+from .common import batch, is_scipy_installed, is_string
 from .data_structures import Lookup, Structure, CaseInsensitiveMapping
-from .verbose import warning
+from .verbose import message_box, warning
 
-__all__ = ['is_scipy_installed', 'is_string']
+__all__ = ['batch', 'is_scipy_installed', 'is_string']
 __all__ += ['Lookup', 'Structure', 'CaseInsensitiveMapping']
-__all__ += ['warning']
+__all__ += ['message_box', 'warning']
